<?php

namespace EventPortal\Domain\Field\Actions;

use EventPortal\Contracts\Respondable;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Enums\Status;
use Illuminate\Support\Arr;
use Illuminate\Support\Str;

class AddInitialFieldsAction
{
    /** @var array */
    private $config;

    public function execute(array $config): Respondable
    {
        $this->config = $config;

        $model = $this->createRespondableModel();

        collect(Arr::get($this->config, 'sections'))
            ->each(function ($rawSection) use ($model): void {
                $section = $this->createSection($rawSection, $model);

                collect(Arr::get($rawSection, 'children'))
                    ->each(function ($child) use ($section, $model): void {
                        $this->createField($section, $model, $child);
                    });
            });

        return $model;
    }

    private function createRespondableModel(): Respondable
    {
        $type = Arr::get($this->config, 'type');

        return $type::create(['status' => Status::PREDRAFT()]);
    }

    private function createSection(array $section, Respondable $model): Field
    {
        $label = Arr::get($section, 'label');

        return Field::create([
            'respondable_id' => $model->id,
            'respondable_type' => Arr::get($this->config, 'type'),
            'label' => $label,
            'name' => Arr::get($section, 'name', Str::slug($label, '_')),
            'type' => Arr::get($section, 'type'),
        ]);
    }

    private function createField(Field $section, Respondable $model, array $child): Field
    {
        $label = Arr::get($child, 'label');

        $field = Field::create([
            'respondable_id' => $model->id,
            'respondable_type' => Arr::get($this->config, 'type'),
            'section_id' => $section->id,
            'type' => Arr::get($child, 'type'),
            'label' => $label,
            'name' => Arr::get($child, 'name', Str::slug($label, '_')),
        ]);

        if (Arr::has($child, 'options')) {
            $field->data->set('options', Arr::get($child, 'options'));
            $field->save();
        }

        if (Arr::has($child, 'validation')) {
            $field->data->set('validation', Arr::get($child, 'validation'));
            $field->save();
        }

        if (Arr::has($child, 'placeholder')) {
            $field->data->set('placeholder', Arr::get($child, 'placeholder'));
            $field->save();
        }

        return $field;
    }
}
