<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class FieldTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function can_scope_for_model()
    {
        $eventA = factory(Event::class)->create();
        $fieldA = factory(Field::class)->create([
            'respondable_id' => $eventA->id,
            'respondable_type' => Event::class,
        ]);

        $eventB = factory(Event::class)->create();
        $fieldB = factory(Field::class)->create([
            'respondable_id' => $eventB->id,
            'respondable_type' => Event::class,
        ]);

        $fields = Field::forModel($eventA)->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldA, $fields);
        $this->assertNotContainsModel($fieldB, $fields);
    }

    /** @test **/
    public function can_scope_to_only_sections()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create();

        $fields = Field::onlySections()->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldB, $fields);
        $this->assertNotContainsModel($fieldA, $fields);
    }

    /** @test **/
    public function can_scope_to_only_children()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create();

        $fields = Field::onlyChildren()->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldA, $fields);
        $this->assertNotContainsModel($fieldB, $fields);
    }

    /** @test **/
    public function can_determine_if_it_is_a_child()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create(['section_id' => null]);

        $this->assertTrue($fieldA->isChild());
        $this->assertFalse($fieldB->isChild());
    }

    /** @test **/
    public function can_determine_if_it_is_a_parent()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create(['section_id' => null]);

        $this->assertFalse($fieldA->isParent());
        $this->assertTrue($fieldB->isParent());
    }
}
