<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Enums\Status;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class RespondableModelTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function can_scope_without_predraft()
    {
        $eventA = factory(Event::class)->state('predraft')->create();
        $eventB = factory(Event::class)->create();

        $events = Event::withoutPredraft()->get();

        $this->assertContainsModel($eventB, $events);
        $this->assertNotContainsModel($eventA, $events);
    }

    /** @test **/
    public function can_set_status()
    {
        $event = factory(Event::class)->state('predraft')->create();

        $this->assertEquals(Status::PREDRAFT(), $event->status);

        $event->setStatus(Status::DRAFT());

        $this->assertEquals(Status::DRAFT(), $event->status);
    }

    /** @test **/
    public function can_handle_haveing_no_validation_rules()
    {
        $event = factory(Event::class)->create();

        $this->assertEquals([], $event->validation_rules);
    }

    /** @test **/
    public function can_get_validation_rules()
    {
        $event = factory(Event::class)->create();
        $field = factory(Field::class)->create([
            'name' => 'event_name',
            'section_id' => 1,
            'respondable_id' => $event->id,
            'respondable_type' => get_class($event),
            'data' => ['validation' => ['required', 'email']]
        ]);

        $this->assertEquals([
            'event_name' => ['required', 'email'],
        ], $event->validation_rules);
    }
}
